# Supported Languages

For languages in the table below that do not rely on ligature support, BabelDOC provides good support. For languages
that partially rely on ligatures, BabelDOC's translation results can generally meet self-reading needs. For languages
that completely rely on ligatures (such as some Indian languages), BabelDOC does not currently support them.

We are working hard to develop support for ligatures as soon as possible.
<!-- | Kazakh (Cyrillic)    | kk            | None                | -->

| Language                        | Language Code | Ligature Dependency |
|:--------------------------------|:--------------|:--------------------|
| English                         | EN            | None                |
| Simplified Chinese              | zh-CN         | None                |
| Traditional Chinese - Hong Kong | zh-HK         | None                |
| Traditional Chinese - Taiwan    | zh-TW         | None                |
| Japanese                        | JA            | None                |
| Korean                          | KO            | None                |
| Polish                          | PL            | Partial             |
| Russian                         | RU            | None                |
| Spanish                         | es            | None                |
| Portuguese                      | pt            | None                |
| French                          | fr            | Partial             |
| Malay                           | ms            | None                |
| Indonesian                      | id            | None                |
| Turkmen                         | tk            | None                |
| Filipino (Tagalog)              | tl            | None                |
| Vietnamese                      | vi            | None                |
| Kazakh (Latin)                  | kk            | None                |
| German                          | de            | None                |
| Dutch                           | nl            | None                |
| Irish                           | ga            | None                |
| Italian                         | it            | None                |
| Greek                           | el            | None                |
| Swedish                         | sv            | None                |
| Danish                          | da            | None                |
| Norwegian                       | no            | None                |
| Icelandic                       | is            | None                |
| Finnish                         | fi            | None                |
| Ukrainian                       | uk            | None                |
| Czech                           | cs            | None                |
| Romanian                        | ro            | None                |
| Hungarian                       | hu            | None                |
| Slovak                          | sk            | None                |
| Croatian                        | hr            | None                |
| Estonian                        | et            | None                |
| Latvian                         | lv            | None                |
| Lithuanian                      | lt            | None                |
| Belarusian                      | be            | None                |
| Macedonian                      | mk            | None                |
| Albanian                        | sq            | None                |
| Serbian (Cyrillic)              | sr            | Partial             |
| Serbian (Latin)                 | sr            | Partial             |
| Slovenian                       | sl            | None                |
| Catalan                         | ca            | None                |
| Bulgarian                       | bg            | None                |
| Maltese                         | mt            | None                |
| Swahili                         | sw            | None                |
| Amharic                         | am            | None                |
| Oromo                           | om            | None                |
| Tigrinya                        | ti            | None                |
| Haitian Creole                  | ht            | None                |
| Latin                           | la            | None                |
| Lao                             | lo            | None                |
| Malayalam                       | ml            | None                |
| Gujarati                        | gu            | None                |
| Thai                            | th            | None                |
| Burmese                         | my            | Partial             |
| Tamil                           | ta            | None                |
| Telugu                          | te            | None                |
| Oriya                           | or            | Partial             |
| Armenian                        | hy            | None                |
| Mongolian (Cyrillic)            | mn            | None                |
| Georgian                        | ka            | None                |
| Khmer                           | km            | None                |
| Bosnian                         | bs            | None                |
| Luxembourgish                   | lb            | None                |
| Moldovan                        | ro            | None                |
| Moldovan (Cyrillic)             | ro            | None                |
| Romansh                         | rm            | None                |
| Turkish                         | tr            | None                |
| Sinhala                         | si            | None                |
| Uzbek                           | uz            | None                |
| Kyrgyz                          | ky            | None                |
| Tajik                           | tg            | None                |
| Abkhazian                       | ab            | None                |
| Afar                            | aa            | None                |
| Afrikaans                       | af            | None                |
| Akan                            | ak            | None                |
| Aragonese                       | an            | None                |
| Avaric                          | av            | None                |
| Ewe                             | ee            | None                |
| Aymara                          | ay            | None                |
| Ojibwa                          | oj            | None                |
| Occitan                         | oc            | None                |
| Oriya                           | or            | None                |
| Ossetian                        | os            | None                |
| Pali                            | pi            | None                |
| Bashkir                         | ba            | None                |
| Basque                          | eu            | None                |
| Breton                          | br            | None                |
| Chamorro                        | ch            | None                |
| Chechen                         | ce            | None                |
| Chuvash                         | cv            | None                |
| Tswana                          | tn            | None                |
| Ndebele, South                  | nr            | None                |
| Ndonga                          | ng            | None                |
| Faroese                         | fo            | None                |
| Fijian                          | fj            | None                |
| Frisian, Western                | fy            | None                |
| Ganda                           | lg            | None                |
| Kongo                           | kg            | None                |
| Kalaallisut                     | kl            | None                |
| Church Slavic                   | cu            | None                |
| Guarani                         | gn            | None                |
| Interlingua                     | ia            | None                |
| Herero                          | hz            | None                |
| Kikuyu                          | ki            | None                |
| Rundi                           | rn            | None                |
| Kinyarwanda                     | rw            | None                |
| Kirghiz                         | ky            | None                |
| Galician                        | gl            | None                |
| Kanuri                          | kr            | None                |
| Cornish                         | kw            | None                |
| Komi                            | kv            | None                |
| Xhosa                           | xh            | None                |
| Corsican                        | co            | None                |
| Cree                            | cr            | None                |
| Croatian                        | hr            | None                |
| Quechua                         | qu            | None                |
| Kurdish (Latin)                 | ku            | None                |
| Kuanyama                        | kj            | None                |
| Limburgan                       | li            | None                |
| Lingala                         | ln            | None                |
| Manx                            | gv            | None                |
| Malagasy                        | mg            | None                |
| Marshallese                     | mh            | None                |
| Maori                           | mi            | None                |
| Navajo                          | nv            | None                |
| Nauru                           | na            | None                |
| Nyanja                          | ny            | None                |
| Norwegian Nynorsk               | nn            | None                |
| Sardinian                       | sc            | None                |
| Northern Sami                   | se            | None                |
| Samoan                          | sm            | None                |
| Sango                           | sg            | None                |
| Shona                           | sn            | None                |
| Esperanto                       | eo            | None                |
| Scottish Gaelic                 | gd            | None                |
| Somali                          | so            | None                |
| Southern Sotho                  | st            | None                |
| Tagalog                         | tl            | None                |
| Tatar                           | tt            | None                |
| Tahitian                        | ty            | None                |
| Tongan                          | to            | None                |
| Twi                             | tw            | None                |
| Walloon                         | wa            | None                |
| Welsh                           | cy            | None                |
| Venda                           | ve            | None                |
| Volapük                         | vo            | None                |
| Interlingue                     | ie            | None                |
| Hiri Motu                       | ho            | None                |
| Igbo                            | ig            | None                |
| Ido                             | io            | None                |
| Inuktitut                       | iu            | None                |
| Inupiaq                         | ik            | None                |
| Sichuan Yi                      | ii            | None                |
| Yoruba                          | yo            | None                |
| Zhuang                          | za            | None                |
| Tsonga                          | ts            | None                |
| Zulu                            | zu            | None                |
| Brazilian Portuguese            | pt-BR         | None                |
